/**
 * The package defining the interfaces for objects that are used by the OAS web service
 */
package com.github.ansell.oas.objects;

import org.openrdf.model.URI;

/**
 * Defines the interface for counting annotations that we are using in the search functionality in
 * the ontology annotation service.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface ResourceCount
{
    /**
     * Increments the count by the given number
     * 
     * @param increment
     *            An integer to increment the count using.
     * @return
     */
    int accumulate(int increment);
    
    /**
     * Returns the count for this object.
     * 
     * @return The count that is stored for this object.
     */
    int getCount();
    
    /**
     * 
     * @return The URI of the resource that this count relates to.
     */
    URI getResourceURI();
    
    /**
     * Sets the count on this object.
     * 
     * @param count
     *            The count for this object.
     */
    void setCount(int count);
    
    /**
     * 
     * @param resource
     *            The URI of the resource that this count relates to.
     */
    void setResourceURI(URI resource);
}
