/**
 * 
 */
package com.github.ansell.oas.utils;

import info.aduna.iteration.Iterations;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.openrdf.model.Resource;
import org.openrdf.model.Statement;
import org.openrdf.repository.RepositoryConnection;
import org.openrdf.repository.RepositoryException;

/**
 * This class contains static methods to help debug contents of an RDF repository
 * 
 * @author kutila
 * 
 */
public class DebugUtils
{
    
    /**
     * Helper method prints the contents of the given context of a Repository
     */
    public static void printContents(final RepositoryConnection conn, final Resource context)
        throws RepositoryException
    {
        System.out.println("==================================================");
        System.out.println("Graph = " + context);
        System.out.println();
        final List<Statement> repoResults = Iterations.asList(conn.getStatements(null, null, null, false, context));
        for(final Statement nextStatement : repoResults)
        {
            System.out.println("   {" + nextStatement.getSubject() + "}   <" + nextStatement.getPredicate() + ">  {"
                    + nextStatement.getObject() + "}");
        }
        System.out.println("==================================================");
    }
    
    /**
     * Helper method prints the contents of the given context of a Repository
     */
    public static void printContexts(final Iterable<Statement> statements)
    {
        System.out.println("==================================================");
        System.out.println("Contexts in collection:  ");
        final Set<Resource> contexts = new HashSet<Resource>();
        for(final Statement nextStatement : statements)
        {
            if(!contexts.contains(nextStatement.getContext()))
            {
                contexts.add(nextStatement.getContext());
                System.out.println(nextStatement.getContext());
            }
        }
        System.out.println("==================================================");
    }
    
    /**
     * Helper method prints the contents of the given context of a Repository
     */
    public static void printContexts(final RepositoryConnection conn) throws RepositoryException
    {
        System.out.println("==================================================");
        System.out.println("Contexts in Repository:  ");
        for(final Resource context : Iterations.asSet(conn.getContextIDs()))
        {
            System.out.println(context);
        }
        System.out.println("==================================================");
    }
    
    public static void printStatements(final Iterable<Statement> statements)
    {
        System.out.println("==================================================");
        System.out.println("Statements: ");
        System.out.println();
        for(final Statement nextStatement : statements)
        {
            System.out.println("   {" + nextStatement.getSubject() + "}   <" + nextStatement.getPredicate() + ">  {"
                    + nextStatement.getObject() + "}");
        }
        System.out.println("==================================================");
    }
    
    public static void printStatements(final Iterable<Statement> statements, final Resource context)
    {
        System.out.println("==================================================");
        System.out.println("Graph = " + context);
        System.out.println("Statements: ");
        System.out.println();
        for(final Statement nextStatement : statements)
        {
            if((context == null && nextStatement.getContext() == null)
                    || (context != null && context.equals(nextStatement.getContext())))
            {
                System.out.println("   {" + nextStatement.getSubject() + "}   <" + nextStatement.getPredicate()
                        + ">  {" + nextStatement.getObject() + "}");
            }
        }
        System.out.println("==================================================");
    }
}
