/**
 * Utility package for OAS
 */
package com.github.ansell.oas.utils;

import java.util.Arrays;
import java.util.List;

import org.openrdf.model.URI;
import org.openrdf.model.ValueFactory;
import org.openrdf.model.impl.ValueFactoryImpl;
import org.openrdf.model.vocabulary.OWL;
import org.openrdf.model.vocabulary.RDFS;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;

/**
 * Contains constants defining the various ontologies and URIs that are used by OAS.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public final class OasConstants
{
    public static final String TAGGING = "http://www.holygoat.co.uk/owl/redwood/0.1/tags/";
    public static final String MOAT = "http://moat-project.org/ns#";
    public static final String FOAF = "http://xmlns.com/foaf/0.1/";
    public static final String DUMMY_ANNOTATION = "urn:tag:dummy:";
    public static final String XSD = "http://www.w3.org/2001/XMLSchema#";
    public static final String DC_TERMS = "http://purl.org/dc/terms/";
    public static final String TAGINSTANCE_NS = "urn:tag:";
    public static final String TAGINSTANCE_LOGOPERATION = "urn:tag:logoperation:";
    public static final String AUTOGENERATED_NS = "urn:tag:autogenerated:";
    public static final String OMV_NS = "http://omv.ontoware.org/ontology#";
    public static final String OAS_NS = "http://purl.org/oas/";
    
    public static final ValueFactory VF = ValueFactoryImpl.getInstance();
    
    public static final URI URN_TAG_USERSIPADDRESS = OasConstants.toURI(OasConstants.TAGINSTANCE_NS, "usersipaddress");
    
    public static final URI URN_TAG_AUDITLOG_RECORD = OasConstants.toURI(OasConstants.TAGINSTANCE_NS, "AuditLogRecord");
    
    public static final URI URN_TAG_AUDITLOG_REF = OasConstants.toURI(OasConstants.TAGINSTANCE_NS, "auditLogRef");
    
    public static final URI URN_TAG_LOGACTION = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION, "action");
    public static final URI URN_TAG_LOGOPERATION_VERB = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION,
            "verb");
    public static final URI URN_TAG_LOGOPERATION_GET = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION, "get");
    public static final URI URN_TAG_LOGOPERATION_UPDATE = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION,
            "update");
    public static final URI URN_TAG_LOGOPERATION_CREATE = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION,
            "create");
    public static final URI URN_TAG_LOGOPERATION_DELETE = OasConstants.toURI(OasConstants.TAGINSTANCE_LOGOPERATION,
            "delete");
    public static final URI URN_TAG_OBJECT_URI_COUNT = OasConstants.toURI(OasConstants.TAGINSTANCE_NS, "UriCountType");
    public static final URI TAGGING_TAGGING = OasConstants.toURI(OasConstants.TAGGING, "Tagging");
    public static final URI TAGGING_NAME = OasConstants.toURI(OasConstants.TAGGING, "name");
    
    public static final URI MOAT_TAG_MEANING = OasConstants.toURI(OasConstants.MOAT, "tagMeaning");
    public static final URI TAGGING_TAGGED_RESOURCE = OasConstants.toURI(OasConstants.TAGGING, "taggedResource");
    public static final URI FOAF_MAKER = OasConstants.toURI(OasConstants.FOAF, "maker");
    public static final URI XSD_DATETIME = OasConstants.toURI(OasConstants.XSD, "dateTime");
    public static final URI XSD_INTEGER = OasConstants.toURI(OasConstants.XSD, "integer");
    public static final URI DC_TERMS_MODIFIED = OasConstants.toURI(OasConstants.DC_TERMS, "modified");
    
    public static final URI OWL_VERSIONIRI = OasConstants.toURI(OWL.NAMESPACE, "versionIRI");
    public static final URI OWL_THING = OasConstants.toURI(OWL.NAMESPACE, "Thing");
    public static final URI OMV_CURRENTVERSION = OasConstants.toURI(OasConstants.OMV_NS, "currentVersion");
    
    public static final URI OAS_ONTOLOGY_SEARCH_RESULT = OasConstants
            .toURI(OasConstants.OAS_NS, "ontologySearchResult");
    public static final URI OAS_INFERREDAXIOMSONTOLOGY = OasConstants.toURI(OasConstants.OAS_NS,
            "inferredAxiomsOntology");
    public static final URI OAS_CURRENTINFERREDAXIOMSONTOLOGY = OasConstants.toURI(OasConstants.OAS_NS,
            "currentInferredAxiomsOntology");
    public static final URI OAS_INPROFILE = OasConstants.toURI(OasConstants.OAS_NS, "inProfile");
    public static final URI OAS_URI_DIRECT_COUNT = OasConstants.toURI(OasConstants.OAS_NS, "uriDirectCount");
    public static final URI OAS_URI_RECURSIVE_COUNT = OasConstants.toURI(OasConstants.OAS_NS, "uriRecursiveCount");
    public static final URI OAS_CONCRETE_AXIOM_COUNT = OasConstants.toURI(OasConstants.OAS_NS, "concreteAxiomCount");
    public static final URI OAS_CONCRETE_LOGICAL_AXIOM_COUNT = OasConstants.toURI(OasConstants.OAS_NS,
            "concreteLogicalAxiomCount");
    public static final URI OAS_INDIVIDUAL_COUNT = OasConstants.toURI(OasConstants.OAS_NS, "individualCount");
    public static final URI OAS_INFERRED_AXIOM_COUNT = OasConstants.toURI(OasConstants.OAS_NS, "inferredAxiomCount");
    
    public static final URI XSD_ANYURI = OasConstants.toURI(OasConstants.XSD, "anyURI");
    
    // FIXME: Avoid hardcoding this. To make this configurable also need to configure the set of
    // profiles that are supported by other reasoners, as they may not support OWL2_DL profile, but
    // may support a smaller subset
    /**
     * This property defines the constant matching the {@link OWLReasonerFactory#getReasonerName()}
     * method for the preferred reasoner implementation.
     * 
     * NOTE: These constants should be defined by all Reasoner factories, although they are not
     * currently used as keys by the upstream version of OWLAPI.
     */
    public static final String OAS_REASONER = "Pellet";
    
    /**
     * The list of label properties that are currently preferred, in order of preference with the
     * first being most preferred.
     */
    public static final List<URI> PREFERRED_LABEL_PROPERTIES = Arrays.asList(RDFS.LABEL);
    
    public static URI toURI(final String nextUri)
    {
        return OasConstants.VF.createURI(nextUri);
    }
    
    public static URI toURI(final String nextNamespace, final String nextUri)
    {
        return OasConstants.VF.createURI(nextNamespace, nextUri);
    }
    
}
