/**
 * 
 */
package com.github.ansell.oas.utils;

import java.util.UUID;

/**
 * Wraps access to the combination of system properties and resource bundle properties for OAS.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public final class OasProps
{
    /**
     * Default identifier for the OAS administration user that is added if there are no other
     * administrators when the application starts up.
     * <p>
     * IMPORTANT: This must be overridden for security.
     */
    public static final String DEF_ADMIN_USER_IDENTIFIER = "testAdminUser";
    
    /**
     * Default password for the OAS administration user that is added if there are no other
     * administrators when the application starts up.
     * <p>
     * IMPORTANT: This must be overridden for security.
     */
    public static final String DEF_ADMIN_USER_SECRET = "testAdminPassword";
    
    /**
     * 
     * 
     * Default value: annotation/countbyobjecturi
     */
    public static final String DEF_ANNOTATION_COUNTS_BY_OBJECT_URI_PATH = "annotation/countbyobjecturi";
    
    /**
     * 
     * 
     * Default value: annotation/countbyontologytermuri
     */
    public static final String DEF_ANNOTATION_COUNTS_BY_ONTOLOGY_TERM_URI_PATH = "annotation/countbyontologytermuri";
    
    /**
     * 
     * 
     * Default value: annotation/id/
     */
    public static final String DEF_ANNOTATION_PATH = "annotation/id/";
    
    /**
     * 
     * 
     * Default value: annotation/byobjecttype
     */
    public static final String DEF_ANNOTATIONS_BY_OBJECT_TYPE_PATH = "annotation/byobjecttype";
    
    /**
     * 
     * 
     * Default value: annotation/byobjecturi
     */
    public static final String DEF_ANNOTATIONS_BY_OBJECT_URI_PATH = "annotation/byobjecturi";
    
    /**
     * 
     * 
     * Default value: annotation/byontologytermuri
     */
    public static final String DEF_ANNOTATIONS_BY_ONTOLOGY_TERM_URI_PATH = "annotation/byontologytermuri";
    
    /**
     * 
     * 
     * Default value: annotation/create
     */
    public static final String DEF_ANNOTATIONS_CREATE_PATH = "annotation/create";
    
    /**
     * 
     * Default value: urn:tag:oas:annotations:managementgraph
     */
    public static final String DEF_ANNOTATIONS_MANAGMENT_GRAPH = "urn:tag:oas:annotations:managementgraph";
    
    /**
     * The default GRAPH URI for the audit log to store its data in.
     * <p>
     * Default value: urn:tag:oas:auditlog:graph
     */
    public static final String DEF_AUDIT_LOG_GRAPH = "urn:tag:oas:auditlog:graph";
    
    /**
     * The default path for the audit log resource.
     * 
     * Default value: "auditlog"
     */
    public static final String DEF_AUDITLOG_PATH = "auditlog";
    
    /**
     * Defaults to true to only allow annotation creation by authenticated users.
     */
    public static final String DEF_AUTH_ANNOTATION_CREATE = "true";
    
    /**
     * Defaults to true to only allow annotation deletion by authenticated users.
     */
    public static final String DEF_AUTH_ANNOTATION_DELETE = "true";
    
    /**
     * Defaults to false to allow unauthenticated annotation reads by default.
     */
    public static final String DEF_AUTH_ANNOTATION_READ = "false";
    
    /**
     * Defaults to true to ensure that ontology creation must be authenticated.
     */
    public static final String DEF_AUTH_ONTOLOGY_CREATE = "true";
    
    /**
     * Defaults to true to ensure that ontology deletion must be authenticated.
     */
    public static final String DEF_AUTH_ONTOLOGY_DELETE = "true";
    
    /**
     * Defaults to false to allow unauthenticated ontology reads by default.
     */
    public static final String DEF_AUTH_ONTOLOGY_READ = "false";
    
    /**
     * Defaults to true to only allow user role editing by authenticated users.
     */
    public static final String DEF_AUTH_ROLE_EDIT = "true";
    
    /**
     * Defaults to true to allow user creation by unauthenticated users.
     */
    public static final String DEF_AUTH_USER_CREATE = "true";
    
    /**
     * Defaults to true to only allow user deletion by authenticated users.
     */
    public static final String DEF_AUTH_USER_DELETE = "true";
    
    /**
     * Defaults to true to only allow browsing of user information by authenticated users.
     */
    public static final String DEF_AUTH_USER_GET = "true";
    
    /**
     * The default path for bulk deletion of annotations.
     * 
     * Default value: annotation/delete
     */
    public static final String DEF_BULK_DELETE_ANNOTATION_PATH = "annotation/delete";
    
    /**
     * The default path for bulk fetching of annotations.
     * 
     * Default value: annotation/fetch
     */
    public static final String DEF_BULK_FETCH_ANNOTATION_PATH = "annotation/fetch";
    
    /**
     * Defaults the OAS challenge authentication method to digest.
     */
    public static final String DEF_CHALLENGE_AUTH_METHOD = "digest";
    
    /**
     * Defaults to true to ensure that challenge authentication is not enabled by default.
     * 
     * If challenge authentication is enabled by default, the cookie-based login page would never
     * show up. However, if we are using digest authentication, the challenge response for any page
     * would enable users to login as necessary for access directly to any page.
     */
    public static final String DEF_CHALLENGE_AUTH_OPTIONAL = "true";
    
    /**
     * Default for the OAS challenge authentication secret.
     * 
     * IMPORTANT: This must be overridden for security.
     * <p>
     * public static final String DEF_CHALLENGE_AUTH_SECRET = "s3cr3t2345667123";
     */
    public static final String DEF_CHALLENGE_AUTH_SECRET = UUID.randomUUID().toString().substring(0, 16);
    
    /**
     * The default path for creating new users.
     * 
     * Default value: user/create
     */
    public static final String DEF_CREATE_USER_PATH = "user/create";
    
    /**
     * The default path for deleting existing users.
     * 
     * Default value: user/delete
     */
    public static final String DEF_DELETE_USER_PATH = "user/delete";
    
    /**
     * The default path for editing user roles.
     * 
     * Default value: roles/edit
     */
    public static final String DEF_EDIT_USER_ROLES_PATH = "roles/edit";
    
    /**
     * The default error message to display when authentication fails while attempting to create
     * annotations.
     */
    public static final String DEF_ERROR_AUTH_ANNOTATION_CREATE =
            "Could not create annotations due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to delete
     * annotations.
     */
    public static final String DEF_ERROR_AUTH_ANNOTATION_DELETE =
            "Could not delete annotations due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to read an
     * annotation.
     */
    public static final String DEF_ERROR_AUTH_ANNOTATION_READ =
            "Could not read annotation due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to create an
     * ontology.
     */
    public static final String DEF_ERROR_AUTH_ONTOLOGY_CREATE =
            "Could not create ontology due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to delete an
     * ontology.
     */
    public static final String DEF_ERROR_AUTH_ONTOLOGY_DELETE =
            "Could not delete ontology due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to read an
     * ontology.
     */
    public static final String DEF_ERROR_AUTH_ONTOLOGY_READ = "Could not read ontology due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to edit a
     * user role.
     */
    public static final String DEF_ERROR_AUTH_ROLE_EDIT = "Could not edit a user role due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to create a
     * user.
     */
    public static final String DEF_ERROR_AUTH_USER_CREATE = "Could not create a user due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to delete a
     * user.
     */
    public static final String DEF_ERROR_AUTH_USER_DELETE = "Could not delete user due to authentication error.";
    
    /**
     * The default error message to display when authentication fails while attempting to get a
     * user.
     */
    public static final String DEF_ERROR_AUTH_USER_GET = "Could not get user details due to authentication error.";
    
    /**
     * The default path for deleting existing users.
     * 
     * Default value: user/delete
     */
    public static final String DEF_GET_USER_PATH = "user";
    
    /**
     * The default path for the base help resources.
     * 
     * Default value: "help/"
     */
    public static final String DEF_HELP_BASE_PATH = "help/";
    
    /**
     * The default path for the specific help resources.
     * 
     * Default value: "help/{page}"
     */
    public static final String DEF_HELP_SUBPAGE_PATH = "help/{page}";
    
    /**
     * The default path for the index resource.
     * 
     * Default value: "" (The empty string)
     */
    public static final String DEF_INDEX_PATH = "";
    
    /**
     * The default path for the login resource to listen to for providing a form.
     * 
     * Default value: login
     */
    public static final String DEF_LOGIN_FORM_PATH = "login";
    
    /**
     * The default path for the login authenticator to automatically process.
     * 
     * Default value: dologin
     */
    public static final String DEF_LOGIN_PATH = "dologin";
    
    /**
     * The default field name to use for redirection after a successful login.
     * 
     * Default value: redirectTo
     */
    public static final String DEF_LOGIN_REDIRECT_FIELD = "targetUri";
    
    /**
     * The default path for the logout resource to listen to for providing a logout response.
     * 
     * Default value: logout
     */
    public static final String DEF_LOGOUT_FORM_PATH = "logout";
    
    /**
     * The default path for the logout authenticator to automatically process.
     * 
     * Default value: dologout
     */
    public static final String DEF_LOGOUT_PATH = "dologout";
    
    /**
     * To default path to use for the ontology browser.
     * 
     * Default value: ontologybrowser/
     */
    public static final String DEF_ONTOLOGY_BROWSER_PATH = "ontologybrowser/";
    
    /**
     * To default path to use when deleting ontologies in the ontology manager from braindead
     * browsers that don't recognise HTTP DELETE as a valid HTTP verb, and hence need to use HTTP
     * POST instead.
     * 
     * Default value: ontologymanager/delete
     */
    public static final String DEF_ONTOLOGY_MANAGER_DELETE_PATH = "ontologymanager/delete";
    
    /**
     * The default GRAPH URI for the ontology manager to store its metadata in.
     * 
     * Default value: urn:tag:oas:ontologymanager:managergraph
     */
    public static final String DEF_ONTOLOGY_MANAGER_GRAPH = "urn:tag:oas:ontologymanager:managergraph";
    
    /**
     * To default path to use for the ontology manager.
     * 
     * Default value: ontologymanager/
     */
    public static final String DEF_ONTOLOGY_MANAGER_PATH = "ontologymanager/";
    
    /**
     * To default path to use for the set current ontology version service.
     * 
     * Default value: ontologymanager/setcurrentversion
     */
    public static final String DEF_SET_CURRENT_VERSION_PATH = "ontologymanager/setcurrentversion";
    
    /**
     * To default path to use when uploading ontologies into the ontology manager from braindead
     * browsers that don't recognise HTTP PUT as a valid HTTP verb, and hence need to use HTTP POST
     * instead.
     * 
     * Default value: ontologymanager/upload
     */
    public static final String DEF_ONTOLOGY_MANAGER_UPLOAD_PATH = "ontologymanager/upload";
    
    /**
     * 
     * Default value: annotation/search
     */
    public static final String DEF_SEARCH_ANNOTATION_PATH = "annotation/search";
    
    /**
     * 
     * Default value: ontologymanager/search
     */
    public static final String DEF_SEARCH_ONTOLOGIES_PATH = "ontologymanager/search";
    
    /**
     * 
     * Default value: ontologymanager/labelsearch
     */
    public static final String DEF_SEARCH_ONTOLOGY_LABELS_PATH = "ontologymanager/labelsearch";
    
    /**
     * 
     * 
     * Default value: oas.annotations.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS = "oas.annotations.html.ftl";
    
    /**
     * 
     * 
     * Default value: annotations.byobjecttype.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYOBJECTTYPE = "annotations.byobjecttype.html.ftl";
    
    /**
     * 
     * 
     * Default value: Annotations (by object type) - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYOBJECTTYPE_TITLE =
            "Annotations (by object type) - Ontology Annotation Services";
    
    /**
     * 
     * 
     * Default value: annotations.byobjecturi.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYOBJECTURI = "annotations.byobjecturi.html.ftl";
    
    /**
     * 
     * 
     * Default value: Annotations (by object URI) - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYOBJECTURI_TITLE =
            "Annotations (by object URI) - Ontology Annotation Services";
    
    /**
     * 
     * 
     * Default value: annotations.byontologytermuri.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYONTOLOGYTERMURI = "annotations.byontologytermuri.html.ftl";
    
    /**
     * 
     * 
     * Default value: Annotations (by ontology term URI) - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_BYONTOLOGYTERMURI_TITLE =
            "Annotations (by ontology term URI) - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.annotations.list.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS_LIST = "oas.annotations.list.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Annotations List - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_LIST_TITLE = "Annotations List - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.annotations.search.html.ftl
     */
    public static final String DEF_TMPL_ANNOTATIONS_SEARCH = "oas.annotations.search.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Annotations Search - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_SEARCH_TITLE = "Annotations Search - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: Annotations - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ANNOTATIONS_TITLE = "Annotations - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.auditlog.html.ftl
     */
    public static final String DEF_TMPL_AUDITLOG = "oas.auditlog.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Audit Log for Ontology Annotation Services
     */
    public static final String DEF_TMPL_AUDITLOG_TITLE = "Audit Log for Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.base.html.ftl
     */
    public static final String DEF_TMPL_BASE = "oas.base.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: oas.error.html.ftl
     */
    public static final String DEF_TMPL_ERROR = "oas.error.html.ftl";
    
    /**
     * This is the base for help files. The help page name is concatenated after it, and the fixed
     * suffix ".html.ftl" is added to determine where the file is located.
     * <p>
     * Default value: help/help_
     */
    public static final String DEF_TMPL_HELP_BASE = "help/help_";
    
    /**
     * 
     * <p>
     * Default value: oas.index.html.ftl
     */
    public static final String DEF_TMPL_INDEX = "oas.index.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Ontology Annotation Services
     */
    public static final String DEF_TMPL_INDEX_TITLE = "Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.login.html.ftl
     */
    public static final String DEF_TMPL_LOGIN = "oas.login.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Login to Ontology Annotation Services
     */
    public static final String DEF_TMPL_LOGIN_TITLE = "Login to Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: oas.logout.html.ftl
     */
    public static final String DEF_TMPL_LOGOUT = "oas.logout.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Logged out of Ontology Annotation Services
     */
    public static final String DEF_TMPL_LOGOUT_TITLE = "Logged out of Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: ontologybrowser.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYBROWSER = "ontologybrowser.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Ontology Browser - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ONTOLOGYBROWSER_TITLE = "Ontology Browser - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: ontologymanager.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER = "ontologymanager.html.ftl";
    
    /**
     * The Default template used to display a form to users to allow them to confirm deletion of a
     * version of an ontology from the ontology manager.
     * <p>
     * Default value: ontologymanager.delete.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_DELETE = "ontologymanager.delete.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: ontologymanager.labelsearch.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_LABELSEARCH = "ontologymanager.labelsearch.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Ontology Label Search - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_LABELSEARCH_TITLE =
            "Ontology Label Search - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: ontologymanager.search.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_SEARCH = "ontologymanager.search.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Ontology Term Search - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_SEARCH_TITLE =
            "Ontology Term Search - Ontology Annotation Services";
    
    /**
     * 
     * <p>
     * Default value: Ontology Manager - Ontology Annotation Services
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_TITLE = "Ontology Manager - Ontology Annotation Services";
    
    /**
     * The Default template used to display a form to users to allow them to easily upload an
     * ontology into the ontology manager.
     * <p>
     * Default value: ontologymanager.upload.html.ftl
     */
    public static final String DEF_TMPL_ONTOLOGYMANAGER_UPLOAD = "ontologymanager.upload.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: oas.role.edit.html.ftl
     */
    public static final String DEF_TMPL_ROLE_EDIT = "oas.role.edit.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Edit a users roles
     */
    public static final String DEF_TMPL_ROLE_EDIT_TITLE = "Edit a users roles";
    
    /**
     * 
     * <p>
     * Default value: oas.user.create.html.ftl
     */
    public static final String DEF_TMPL_USER_CREATE = "oas.user.create.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Create a new user
     */
    public static final String DEF_TMPL_USER_CREATE_TITLE = "Create a new user";
    
    /**
     * 
     * <p>
     * Default value: oas.user.delete.html.ftl
     */
    public static final String DEF_TMPL_USER_DELETE = "oas.user.delete.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Delete user
     */
    public static final String DEF_TMPL_USER_DELETE_TITLE = "Delete user";
    
    /**
     * 
     * <p>
     * Default value: oas.user.html.ftl
     */
    public static final String DEF_TMPL_USER_GET = "oas.user.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: User
     */
    public static final String DEF_TMPL_USER_GET_TITLE = "User";
    
    /**
     * 
     * <p>
     * Default value: oas.user.update.html.ftl
     */
    public static final String DEF_TMPL_USER_UPDATE = "oas.user.update.html.ftl";
    
    /**
     * 
     * <p>
     * Default value: Update user
     */
    public static final String DEF_TMPL_USER_UPDATE_TITLE = "Update user";
    
    /**
     * The default path for updating existing users.
     * <p>
     * Default value: user/update
     */
    public static final String DEF_UPDATE_USER_PATH = "user/update";
    
    /**
     * The default GRAPH URI for the user manager to store its data in.
     * <p>
     * Default value: urn:tag:oas:usermanager:managergraph
     */
    public static final String DEF_USER_MANAGER_GRAPH = "urn:tag:oas:usermanager:managergraph";
    
    /**
     * The default path for the whoami service.
     * <p>
     * Default value: whoami
     */
    public static final String DEF_WHOAMI_PATH = "whoami";
    
    /**
     * Parameter used in HTTP queries on the annotation services to represent an annotation id.
     */
    public static final String PARAM_ANNOTATIONID = "annotationId";
    
    /**
     * Property used to set the default admin user identifier to use if there is no other admin user
     * existing in the system.
     */
    public static final String PROP_ADMIN_USER_IDENTIFIER = "oas.webserviceapi.auth.admin.identifier.default";
    
    /**
     * Property used to set the default admin user secret to use if there is no other admin user
     * existing in the system.
     */
    public static final String PROP_ADMIN_USER_SECRET = "oas.webserviceapi.auth.admin.secret.default";
    
    /**
     * The REST URL path that will be used to count the number of annotations that reference a given
     * annotated object URI.
     */
    public static final String PROP_ANNOTATION_COUNTS_BY_OBJECT_URI_PATH = "oas.annotations.countbyobjecturi.path";
    
    /**
     * The REST URL path that will be used to count the number of annotations that reference a given
     * ontology term.
     */
    public static final String PROP_ANNOTATION_COUNTS_BY_ONTOLOGY_TERM_URI_PATH =
            "oas.annotations.countbyontologytermuri.path";
    
    /**
     * The REST URL path that will be matched with the create new annotation web service.
     */
    public static final String PROP_ANNOTATION_CREATE_PATH = "oas.annotations.create.path";
    
    /**
     * The URI for the annotation management to store its metadata in.
     */
    public static final String PROP_ANNOTATION_MANAGMENT_GRAPH = "oas.annotations.managementgraph";
    
    /**
     * The REST URL path that will be used to perform actions on existing annotations.
     */
    public static final String PROP_ANNOTATION_PATH = "oas.annotations.path";
    
    /**
     * The REST URL path that will be used to perform searches for annotations based on the type of
     * the object being annotated.
     */
    public static final String PROP_ANNOTATIONS_BY_OBJECT_TYPE_PATH = "oas.annotations.byobjecttype.path";
    
    /**
     * The REST URL path that will be used to perform searches for annotations based on the URI of
     * the object being annotated.
     */
    public static final String PROP_ANNOTATIONS_BY_OBJECT_URI_PATH = "oas.annotations.byobjecturi.path";
    
    /**
     * The REST URL path that will be used to perform searches for annotations based on the ontology
     * term used in the annotations.
     */
    public static final String PROP_ANNOTATIONS_BY_ONTOLOGY_TERM_URI_PATH = "oas.annotations.byontologytermuri.path";
    
    /**
     * The URI for the user manager to store its information in.
     * 
     */
    public static final String PROP_AUDIT_LOG_GRAPH = "oas.auditlog.graph";
    
    /**
     * The path to use to display a index page to users
     */
    public static final String PROP_AUDITLOG_PATH = "oas.auditlog.path";
    
    /**
     * True if authentication is required to create annotations and false otherwise.
     */
    public static final String PROP_AUTH_ANNOTATION_CREATE = "oas.webserviceapi.auth.annotation.create";
    
    /**
     * True if authentication is required to delete annotations and false otherwise.
     */
    public static final String PROP_AUTH_ANNOTATION_DELETE = "oas.webserviceapi.auth.annotation.delete";
    
    /**
     * True if authentication is required to read annotations and false if no authentication is
     * required.
     */
    public static final String PROP_AUTH_ANNOTATION_READ = "oas.webserviceapi.auth.annotation.read";
    
    /**
     * True if authentication is required to create ontologies and false if no authentication is
     * required.
     */
    public static final String PROP_AUTH_ONTOLOGY_CREATE = "oas.webserviceapi.auth.ontology.create";
    
    /**
     * True if authentication is required to delete ontologies and false if no authentication is
     * required.
     */
    public static final String PROP_AUTH_ONTOLOGY_DELETE = "oas.webserviceapi.auth.ontology.delete";
    
    /**
     * True if authentication is required to read ontologies and false if no authentication is
     * required.
     */
    public static final String PROP_AUTH_ONTOLOGY_READ = "oas.webserviceapi.auth.ontology.read";
    
    /**
     * True if authentication is required to edit users roles and false if an unauthenticated
     * visitor can edit users roles.
     */
    public static final String PROP_AUTH_ROLE_EDIT = "oas.webserviceapi.auth.role.edit";
    
    /**
     * True if authentication is required to create users and false if an unauthenticated visitor
     * can create a new user.
     */
    public static final String PROP_AUTH_USER_CREATE = "oas.webserviceapi.auth.user.create";
    
    /**
     * True if authentication is required to delete users and false if an unauthenticated visitor
     * can delete a user.
     */
    public static final String PROP_AUTH_USER_DELETE = "oas.webserviceapi.auth.user.delete";
    
    /**
     * True if authentication is required to browse users and false if an unauthenticated visitor
     * can browse users.
     */
    public static final String PROP_AUTH_USER_GET = "oas.webserviceapi.auth.user.get";
    
    /**
     * The path to use to delete annotations in bulk.
     */
    public static final String PROP_BULK_DELETE_ANNOTATION_PATH = "oas.annotations.bulkdelete";
    
    /**
     * The path to use to fetch annotations in bulk.
     */
    public static final String PROP_BULK_FETCH_ANNOTATION_PATH = "oas.annotations.bulkfetch";
    
    /**
     * The challenge authentication method to use.
     * 
     * Can be http, digest, or cookie.
     */
    public static final String PROP_CHALLENGE_AUTH_METHOD = "oas.webserviceapi.auth.challenge.method";
    
    /**
     * True if challenge authentication is optional, and false if challenge authentication is not
     * optional.
     */
    public static final String PROP_CHALLENGE_AUTH_OPTIONAL = "oas.webserviceapi.auth.challenge.optional";
    
    /**
     * The challenge authentication secret to use.
     */
    public static final String PROP_CHALLENGE_AUTH_SECRET = "oas.webserviceapi.auth.challenge.secret";
    
    /**
     * The path to use to create new users.
     */
    public static final String PROP_CREATE_USER_PATH = "oas.user.create.form.path";
    
    /**
     * The path to use to delete existing users.
     */
    public static final String PROP_DELETE_USER_PATH = "oas.user.delete.form.path";
    
    /**
     * The path to use to edit user roles.
     */
    public static final String PROP_EDIT_USER_ROLES_PATH = "oas.roles.edit.form.path";
    
    /**
     * The error message to display when authentication fails while attempting to create
     * annotations.
     */
    public static final String PROP_ERROR_AUTH_ANNOTATION_CREATE = "oas.error.auth.annotation.create";
    
    /**
     * The error message to display when authentication fails while attempting to delete
     * annotations.
     */
    public static final String PROP_ERROR_AUTH_ANNOTATION_DELETE = "oas.error.auth.annotation.delete";
    
    /**
     * The error message to display when authentication fails while attempting to read an
     * annotation.
     */
    public static final String PROP_ERROR_AUTH_ANNOTATION_READ = "oas.error.auth.annotation.read";
    
    /**
     * The error message to display when authentication fails while attempting to create an
     * ontology.
     */
    public static final String PROP_ERROR_AUTH_ONTOLOGY_CREATE = "oas.error.auth.ontology.create";
    
    /**
     * The error message to display when authentication fails while attempting to delete an
     * ontology.
     */
    public static final String PROP_ERROR_AUTH_ONTOLOGY_DELETE = "oas.error.auth.ontology.delete";
    
    /**
     * The error message to display when authentication fails while attempting to read an ontology.
     */
    public static final String PROP_ERROR_AUTH_ONTOLOGY_READ = "oas.error.auth.ontology.read";
    
    /**
     * The error message to display when authentication fails while attempting to edit a users
     * roles.
     */
    public static final String PROP_ERROR_AUTH_ROLE_EDIT = "oas.error.auth.role.edit";
    
    /**
     * The error message to display when authentication fails while attempting to create a new user.
     */
    public static final String PROP_ERROR_AUTH_USER_CREATE = "oas.error.auth.user.create";
    
    /**
     * The error message to display when authentication fails while attempting to delete a user.
     */
    public static final String PROP_ERROR_AUTH_USER_DELETE = "oas.error.auth.user.delete";
    
    /**
     * The error message to display when authentication fails while attempting to get user details.
     */
    public static final String PROP_ERROR_AUTH_USER_GET = "oas.error.auth.user.get";
    
    /**
     * The path to use to browse users.
     */
    public static final String PROP_GET_USER_PATH = "oas.user.get.form.path";
    
    /**
     * The path to use to display the base help page to users
     */
    public static final String PROP_HELP_BASE_PATH = "oas.help.base.path";
    
    /**
     * The path to use to display specific help pages to users
     */
    public static final String PROP_HELP_SUBPAGE_PATH = "oas.help.subpage.path";
    
    /**
     * The path to use to display a index page to users
     */
    public static final String PROP_INDEX_PATH = "oas.index.path";
    
    /**
     * The path to use to display a login form to users.
     */
    public static final String PROP_LOGIN_FORM_PATH = "oas.login.form.path";
    
    /**
     * The path to use to submitting login information to OAS.
     */
    public static final String PROP_LOGIN_PATH = "oas.login.path";
    
    /**
     * The field in a login request to use to redirect to after a successful login.
     */
    public static final String PROP_LOGIN_REDIRECT_FIELD = "oas.login.redirect.field";
    
    /**
     * The path to use after logging out of OAS.
     */
    public static final String PROP_LOGOUT_FORM_PATH = "oas.logout.form.path";
    
    /**
     * The path to use to logging out of OAS.
     */
    public static final String PROP_LOGOUT_PATH = "oas.logout.path";
    
    /**
     * The path to use when interacting with the ontology browser from a full HTTP client.
     */
    public static final String PROP_ONTOLOGY_BROWSER_PATH = "oas.ontologybrowser.path";
    
    /**
     * The path to use when deleting ontologies from the ontology manager from browsers that do not
     * fully support HTTP.
     */
    public static final String PROP_ONTOLOGY_MANAGER_DELETE_PATH = "oas.ontologymanager.delete.path";
    
    /**
     * The URI for the ontology manager to store its information in.
     * 
     */
    public static final String PROP_ONTOLOGY_MANAGER_GRAPH = "oas.ontologymanager.managergraph";
    
    /**
     * The path to use when interacting with the ontology manager from a full HTTP client.
     */
    public static final String PROP_ONTOLOGY_MANAGER_PATH = "oas.ontologymanager.path";
    
    /**
     * The path to use when setting the current version for an ontology.
     */
    public static final String PROP_SET_CURRENT_VERSION_PATH = "oas.ontologymanager.setcurrentversion.path";
    
    /**
     * The path to use when uploading ontologies into the ontology manager from browsers that do not
     * fully support HTTP.
     */
    public static final String PROP_ONTOLOGY_MANAGER_UPLOAD_PATH = "oas.ontologymanager.upload.path";
    
    /**
     * The path portion of the URI for the search annotations web service.
     */
    public static final String PROP_SEARCH_ANNOTATION_PATH = "oas.search.annotations";
    
    /**
     * The path portion of the URI for the search ontologies web service.
     */
    public static final String PROP_SEARCH_ONTOLOGIES_PATH = "oas.search.ontologies";
    
    /**
     * The path portion of the URI for the search ontology labels web service.
     */
    public static final String PROP_SEARCH_ONTOLOGY_LABELS_PATH = "oas.search.ontologylabels";
    
    /**
     * The URL to look for the sesame repository in.
     * 
     * No default for this. If they do not specify a URL, we create a temporary in-memory store
     */
    public static final String PROP_SESAME_URL = "oas.sesame.url";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS = "oas.template.annotations";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYOBJECTTYPE = "oas.template.annotations.byobjecttype";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYOBJECTTYPE_TITLE = "oas.template.annotations.byobjecttype.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYOBJECTURI = "oas.template.annotations.byobjecturi";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYOBJECTURI_TITLE = "oas.template.annotations.byobjecturi.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYONTOLOGYTERMURI = "oas.template.annotations.byontologytermuri";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_BYONTOLOGYTERMURI_TITLE =
            "oas.template.annotations.byontologytermuri.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_LIST = "oas.template.annotations.list";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_LIST_TITLE = "oas.template.annotations.list.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_SEARCH = "oas.template.annotations.search";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_SEARCH_TITLE = "oas.template.annotations.search.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ANNOTATIONS_TITLE = "oas.template.annotations.title";
    
    /**
     * The property to set a custom template for the Audit Log page.
     */
    public static final String PROP_TMPL_AUDITLOG = "oas.template.auditlog";
    
    /**
     * The property to set a custom title for the Audit Log page.
     */
    public static final String PROP_TMPL_AUDITLOG_TITLE = "oas.template.auditlog.title";
    
    /**
     * 
     */
    public static final String PROP_TMPL_BASE = "oas.template.base";
    
    /**
     * 
     */
    public static final String PROP_TMPL_ERROR = "oas.template.error";
    
    /**
     * 
     */
    public static final String PROP_TMPL_HELP_BASE = "oas.template.help.base";
    
    /**
     * The property to set a custom template for the Index page.
     */
    public static final String PROP_TMPL_INDEX = "oas.template.index";
    
    /**
     * The property to set a custom title for the Index page.
     */
    public static final String PROP_TMPL_INDEX_TITLE = "oas.template.index.title";
    
    /**
     * The property to set a custom template for the Login HTML interface.
     */
    public static final String PROP_TMPL_LOGIN = "oas.template.login";
    
    /**
     * The property to set a custom title for the Login HTML interface.
     */
    public static final String PROP_TMPL_LOGIN_TITLE = "oas.template.login.title";
    
    /**
     * The property to set a custom template for the Logout HTML interface.
     */
    public static final String PROP_TMPL_LOGOUT = "oas.template.logout";
    
    /**
     * The property to set a custom title for the Logout HTML interface.
     */
    public static final String PROP_TMPL_LOGOUT_TITLE = "oas.template.logout.title";
    
    /**
     * The property to set a custom template for the Ontology Browser HTML interface.
     */
    public static final String PROP_TMPL_ONTOLOGYBROWSER = "oas.template.ontologybrowser";
    
    /**
     * The title used for the ontology browser base template.
     */
    public static final String PROP_TMPL_ONTOLOGYBROWSER_TITLE = "oas.template.ontologybrowser.title";
    
    /**
     * The property to set a custom template for the Ontology Manager HTML interface.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER = "oas.template.ontologymanager";
    
    /**
     * The property to set a custom template for the HTML interface to be shown to users to enable
     * them to confirm deletion of a single version of an ontology from the ontology manager.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_DELETE = "oas.template.ontologymanagerdelete";
    
    /**
     * The property to set a custom template for the Ontology Label Search HTML interface.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_LABELSEARCH = "oas.template.ontologymanager.labelsearch";
    
    /**
     * The title used for the ontology manager label search template.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_LABELSEARCH_TITLE =
            "oas.template.ontologymanager.labelsearch.title";
    
    /**
     * The property to set a custom template for the Ontology Term Search HTML interface.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_SEARCH = "oas.template.ontologymanager.search";
    
    /**
     * The title used for the ontology manager search template.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_SEARCH_TITLE = "oas.template.ontologymanager.search.title";
    
    /**
     * The title used for the ontology manager base template.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_TITLE = "oas.template.ontologymanager.title";
    
    /**
     * The property to set a custom template for the HTML interface to be shown to users who want to
     * upload ontologies into the ontology manager.
     */
    public static final String PROP_TMPL_ONTOLOGYMANAGER_UPLOAD = "oas.template.ontologymanagerupload";
    
    /**
     * The property to set a custom template for the edit user roles HTML interface.
     */
    public static final String PROP_TMPL_ROLE_EDIT = "oas.template.role.edit";
    
    /**
     * The property to set a custom title for the edit user roles HTML interface.
     */
    public static final String PROP_TMPL_ROLE_EDIT_TITLE = "oas.template.role.edit.title";
    
    /**
     * The property to set a custom template for the create user HTML interface.
     */
    public static final String PROP_TMPL_USER_CREATE = "oas.template.user.create";
    
    /**
     * The property to set a custom title for the create user HTML interface.
     */
    public static final String PROP_TMPL_USER_CREATE_TITLE = "oas.template.user.create.title";
    
    /**
     * The property to set a custom template for the delete user HTML interface.
     */
    public static final String PROP_TMPL_USER_DELETE = "oas.template.user.delete";
    
    /**
     * The property to set a custom title for the delete user HTML interface.
     */
    public static final String PROP_TMPL_USER_DELETE_TITLE = "oas.template.user.delete.title";
    
    /**
     * The property to set a custom template for the get user HTML interface.
     */
    public static final String PROP_TMPL_USER_GET = "oas.template.user.get";
    
    /**
     * The property to set a custom title for the create user HTML interface.
     */
    public static final String PROP_TMPL_USER_GET_TITLE = "oas.template.user.get.title";
    
    /**
     * The property to set a custom template for the update user HTML interface.
     */
    public static final String PROP_TMPL_USER_UPDATE = "oas.template.user.update";
    
    /**
     * The property to set a custom title for the update user HTML interface.
     */
    public static final String PROP_TMPL_USER_UPDATE_TITLE = "oas.template.user.update.title";
    
    /**
     * The path to use to update existing users.
     */
    public static final String PROP_UPDATE_USER_PATH = "oas.user.update.form.path";
    
    /**
     * The URI for the user manager to store its information in.
     * 
     */
    public static final String PROP_USER_MANAGER_GRAPH = "oas.usermanager.managergraph";
    
    /**
     * The path to use to find current user information.
     */
    public static final String PROP_WHOAMI_PATH = "oas.whoami.path";
    
    /**
     * Private default constructor.
     */
    private OasProps()
    {
        // should not need to instantiate this class by design, it pulls its state directly from a
        // single properties file and the global system vm property state
        // XXX: should we allow people to change the default properties bundle name?
        // They can use system vm properties (ie, -Doas.property.name=value) to change any of these
        // at a higher priority than the properties file
    }
    
}
