package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.representation.Variant;
import org.restlet.resource.Delete;
import org.restlet.resource.Get;
import org.restlet.resource.Put;
import org.restlet.resource.ResourceException;

/**
 * Interface for the Ontology Annotation Web Service providing the ability to create, update, delete
 * and get annotations.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface AnnotationByIdResource
{
    /**
     * Remove this resource.
     */
    @Delete
    void deleteAnnotation() throws ResourceException;
    
    /**
     * Generate the HTML representation of this resource.
     */
    @Get(":html")
    Representation getHtml(Variant variant) throws ResourceException;
    
    /**
     * Generate the RDF representation of this resource.
     */
    @Get(":rdf|rj|json|ttl")
    Representation getRdf(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Update the underlying contact according to the given representation.
     * 
     * @return The resulting annotation, including any changes in the URIs.
     */
    @Put(":html")
    Representation putAnnotationHtml(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Update the underlying contact according to the given representation.
     * 
     * @return The resulting annotation, including any changes in the URIs.
     */
    @Put(":rdf|rj|json|ttl")
    Representation putAnnotationRdf(Representation entity, Variant variant) throws ResourceException;
    
}