package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.representation.Variant;
import org.restlet.resource.Get;
import org.restlet.resource.Post;
import org.restlet.resource.ResourceException;

/**
 * Interface for the Ontology Annotation Web Service providing the ability to get multiple
 * annotations.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface BulkFetchAnnotationResource
{
    /**
     * Respond to HTTP GET requests for HTML by listing annotations.
     */
    @Get(":html")
    Representation getToHtml(Variant variant) throws ResourceException;
    
    /**
     * Respond to HTTP GET requests for RDF formats by listing annotations.
     */
    @Get(":rdf|rj|json|ttl")
    Representation getToRdf(Variant variant) throws ResourceException;
    
    /**
     * Accept POST for bulk retrieval and response with the HTML representation of this resource.
     */
    @Post(":html")
    Representation postToHtml(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Accept POST for bulk retrieval and response with the RDF representation of this resource.
     */
    @Post(":rdf|rj|json|ttl")
    Representation postToRdf(Representation entity, Variant variant) throws ResourceException;
    
}