package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.resource.Get;
import org.restlet.resource.Post;
import org.restlet.resource.Put;
import org.restlet.resource.ResourceException;

/**
 * Version of the Ontology Resource that allows the use of HTTP POST to create ontologies for
 * browsers who only support HTTP GET and HTTP POST.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface CreateOntologyResource
{
    /**
     * Update the underlying ontology using a MultiPart representation with an HTTP POST request.
     * 
     * This method needs to be distinct from OntologyResource to avoid confusing it with respect to
     * POST as a poor substitute for HTTP DELETE for DeleteOntologyResource.
     * 
     * Responses to multi-part queries redirect the user using HTTP 303 See Also status code to the
     * ontology manager.
     */
    @Post("multipart")
    Representation createOntologyMultiPartByPost(Representation entity) throws ResourceException;
    
    /**
     * Update the underlying ontology using an RDF representation with an HTTP POST request.
     * 
     * This method needs to be distinct from OntologyResource to avoid confusing it with respect to
     * POST as a poor substitute for HTTP DELETE for DeleteOntologyResource.
     * 
     * @return The resulting annotation, including any changes in the URIs.
     */
    @Post("rdf")
    Representation createOntologyRdfByPost(Representation entity) throws ResourceException;
    
    /**
     * Update the underlying ontology using an RDF representation with an HTTP PUT request.
     * 
     * This method wraps createOntologyRdf in OntologyResourc.e
     * 
     * @return The resulting annotation, including any changes in the URIs.
     */
    @Put("rdf")
    Representation createOntologyRdfByPut(Representation entity) throws ResourceException;
    
    /**
     * Fetch a form that can be used in an HTML application to upload a new ontology.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Get("html")
    Representation getUploadPageHtml(Representation entity) throws ResourceException;
    
}