package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.representation.Variant;
import org.restlet.resource.Delete;
import org.restlet.resource.Get;
import org.restlet.resource.Post;
import org.restlet.resource.ResourceException;

/**
 * Version of the Ontology Resource that allows the use of HTTP POST to delete ontologies for
 * browsers who only support HTTP GET and HTTP POST.
 * 
 * In practice, this should simply call the OntologyResource.delete method.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface DeleteOntologyResource
{
    /**
     * Remove this resource, using the parameter ontologyUri and the optional parameter
     * managedOntologyVersionUri to specify which ontology, or versions of the ontology to delete.
     * 
     * This wraps the REST version in OntologyResource which uses also HTTP DELETE.
     */
    @Delete
    void deleteOntologyByDelete(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Remove this resource, using the parameter ontologyUri and the optional parameter
     * managedOntologyVersionUri to specify which ontology, or versions of the ontology to delete.
     * 
     * This wraps the true REST version in OntologyResource which uses HTTP DELETE.
     * 
     * Cannot put this version on that resource, or it would not be able to automatically
     * distinguish between a Delete POST operation and a Create POST operation.
     * 
     */
    @Post
    void deleteOntologyByPost(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Retrieve a form that can be used to confirm the deletion of an ontology in an HTML
     * application.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Get("html")
    Representation getDeletePageHtml(Representation entity) throws ResourceException;
    
}