package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.representation.Variant;
import org.restlet.resource.Delete;
import org.restlet.resource.Get;
import org.restlet.resource.Put;
import org.restlet.resource.ResourceException;

/**
 * Interface for the Ontology Annotation Web Service providing the ability to create, update, delete
 * and get ontologies using HTTP PUT, DELETE and GET.
 * 
 * HTTP POST for both deleting and creating ontologies is supported using DeleteOntologyResource and
 * CreateOntologyResource respectively.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface OntologyManagerResource
{
    /**
     * Remove this resource, using the parameter ontologyUri and the optional parameter
     * managedOntologyVersionUri to specify which ontology, or versions of the ontology to delete.
     */
    @Delete
    void deleteOntology() throws ResourceException;
    
    /**
     * Generate the HTML/RDFa representation of this resource.
     */
    @Get("html")
    Representation getHtml(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Generate the RDF representation of this resource.
     */
    @Get(":rdf|rj|json|ttl")
    Representation getRdf(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Update the underlying ontology using an RDF representation.
     * 
     * @return The resulting annotation, including any changes in the URIs.
     */
    @Put("rdf")
    Representation putOntologyRdf(Representation entity) throws ResourceException;
}