package com.github.ansell.oas.webservice;

import org.restlet.representation.Representation;
import org.restlet.representation.Variant;
import org.restlet.resource.Delete;
import org.restlet.resource.Get;
import org.restlet.resource.Put;
import org.restlet.resource.ResourceException;

/**
 * Central form for user information
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public interface UserResource
{
    /**
     * Handles DELETE requests to delete an existing user.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Delete
    Representation deleteUser(Representation entity) throws ResourceException;
    
    /**
     * Gets information about a user in HTML.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Get("html")
    Representation getUserHtml(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Gets information about a user in RDF.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Get(":rdf|rj|json|ttl")
    Representation getUserRdfXml(Representation entity, Variant variant) throws ResourceException;
    
    /**
     * Handles PUT requests to create a new user.
     * 
     * @param entity
     * @return
     * @throws ResourceException
     */
    @Put
    Representation putCreateUserMultipart(Representation entity) throws ResourceException;
    
}